@@ -1,6 +1,6 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond.model import fields, ModelView, Workflow
+from trytond.model import fields
 from trytond.pyson import Eval
 from trytond.pool import Pool, PoolMeta
 from trytond.transaction import Transaction
@@ -9,10 +9,10 @@ from trytond.tools import grouped_slice
 
 __all__ = ['PurchaseRequest', 'PurchaseConfig', 'Purchase', 'PurchaseLine',
     'ProductSupplier', 'CreatePurchase', 'PurchaseHandleShipmentException']
-__metaclass__ = PoolMeta
 
 
 class PurchaseRequest:
+    __metaclass__ = PoolMeta
     __name__ = 'purchase.request'
 
     customer = fields.Many2One('party.party', 'Customer', readonly=True,
@@ -29,6 +29,7 @@ class PurchaseRequest:
 
 
 class PurchaseConfig:
+    __metaclass__ = PoolMeta
     __name__ = 'purchase.configuration'
 
     purchase_drop_location = fields.Property(
@@ -37,6 +38,7 @@ class PurchaseConfig:
 
 
 class Purchase:
+    __metaclass__ = PoolMeta
     __name__ = 'purchase.purchase'
 
     customer = fields.Many2One('party.party', 'Customer', readonly=True,
@@ -122,26 +124,9 @@ class Purchase:
             delivery_address=self.delivery_address,
             )
 
-    @classmethod
-    @ModelView.button
-    @Workflow.transition('cancel')
-    def cancel(cls, purchases):
-        pool = Pool()
-        SaleLine = pool.get('sale.line')
-        Move = pool.get('stock.move')
-
-        super(Purchase, cls).cancel(purchases)
-        sale_lines = []
-        for sub_purchases in grouped_slice(purchases):
-            sale_lines += SaleLine.search([
-                    ('purchase_request.purchase_line.purchase', 'in',
-                        [p.id for p in sub_purchases]),
-                    ])
-        Move.cancel([m for sl in sale_lines for m in sl.moves
-                if m.state != 'done' and m.from_location.type == 'drop'])
-
 
 class PurchaseLine:
+    __metaclass__ = PoolMeta
     __name__ = 'purchase.line'
 
     def get_to_location(self, name):
@@ -150,14 +135,15 @@ class PurchaseLine:
             return self.purchase.drop_location.id
         return result
 
-    def get_move(self):
-        move = super(PurchaseLine, self).get_move()
+    def get_move(self, move_type):
+        move = super(PurchaseLine, self).get_move(move_type)
         if move and self.purchase.customer:
             move.cost_price = move.unit_price
         return move
 
 
 class ProductSupplier:
+    __metaclass__ = PoolMeta
     __name__ = 'purchase.product_supplier'
 
     drop_shipment = fields.Boolean('Drop Shipment',
@@ -168,6 +154,7 @@ class ProductSupplier:
 
 
 class CreatePurchase:
+    __metaclass__ = PoolMeta
     __name__ = 'purchase.request.create_purchase'
 
     @classmethod
@@ -183,6 +170,7 @@ class CreatePurchase:
 
 
 class PurchaseHandleShipmentException:
+    __metaclass__ = PoolMeta
     __name__ = 'purchase.handle.shipment.exception'
 
     def transition_handle(self):
